## Choice of ketchup brands

Choice behavior for 300 individuals in a panel of households in Springfield, Missouri (USA). The data captures information on 2,798 purchase occasions over a period of around 2 years and includes the follow variables:

* id: Individual identifier
* choice: One of heinz41, heinz32, heinz28, hunts32
* price.x: Price of product x
* disp.x: Is there a display for product x? 
* feat.x: Is there a newspaper feature advertisement for product x?

Source: Jain DC, Vilcassim NJ, Chintagunta PK (1994). "A Random-Coefficients Logit Brand-Choice Model Applied to Panel Data." Journal of Business \& Economic Statistics, 12(3), 317-328.
